#clearing previous workspace
rm(list=ls())


######## 1)
#Load in the ant-tanager data and do the following data manipulations or mathematical functions:
#import in the data
tan.dat <- read.csv("ant-tanager data.csv")

#A) Save the mass value for the dominant male in group 5
a <- tan.dat[5,4]

#B) Save the first row of the data frame as a vector
row <- tan.dat[1,]

#C) Calculate the average mass of all ant-tanagers, using the mean function
mean(tan.dat$mass)

#D) Calculate the variance of helper ant-tanager brightness, using the var function
helper.brightness <- subset(tan.dat$brightness, tan.dat$statu=="helper")
var(helper.brightness)

#E) Calculate the standard error of dominant ant-tanager brightness. 
dominant.brightness <- subset(tan.dat$brightness, tan.dat$statu=="dominant")
sqrt(var(dominant.brightness)/length(dominant.brightness))

#F) save the names of the data frame as a vector
tan.names <- names(tan.dat)


######## 2)
#Use a two-sample t-test to see if dominant ant-tanagers are generally less bright than their helpers and plot the results using a barplot

#A) separate out the helper and dominant brightness data
helper.brightness <- subset(tan.dat$brightness, tan.dat$status=="helper")
dominant.brightness <- subset(tan.dat$brightness, tan.dat$status=="dominant")

#B) use a two-sample t-test on the data
t.test(helper.brightness, dominant.brightness, var=TRUE)

#C) plot the means and standard deviations of the data using a barplot with the functions tapply and arrows
#calculating means and sds using tapply
means <- tapply(tan.dat$brightness, tan.dat$status, mean)
sds <- tapply(tan.dat$brightness, tan.dat$status, sd)

#getting x coordinates of barplot
x.coords <- barplot(means)

#making the figure
barplot(means, ylab="Percent Brightness (%)", xlab="Ant-tanager Status", names.arg=c("Dominant", "Helper"), ylim=c(0,30), col=c("grey","white"))
arrows(x.coords, means-sds, x.coords, means+sds, length=0.1, angle=90, code=3, lwd=2)

#D) What are your conclusions of the t.test
#Helpers are significantly  brighter than dominant ant-tanagers

######## 3)
#Use an ANOVA (with post-hoc tests) to test if there is an effect of habitat on dominant ant-tanager mass and plot the results using a box and whisker plot. 

#A) Subset the dominant ant-tanager data
dominants <- subset(tan.dat, tan.dat$status=="dominant")

#B) Run the ANOVA on the data
anova(anova.model)

#C) Run the Tukey-Kramer post-hoc tests
tk.model <- aov(mass~habitat, data=dominants)
TukeyHSD(tk.model)

#D) Make a box-and-whisker plot of the data
boxplot(mass~habitat, data=dominants, ylab="Mass (g)", xlab="Habitat", names=c("Edge", "Forest", "Open"), col=c("Grey","Green", "White"))

#E) What are your conclusions of the ANOVA and Tukey-Kramer tests?
#There is a significant effect of habitat on dominant ant-tanager body size
#Open habitat dominant ant-tanagers are significantly smaller than forest habitat dominant ant-tanagers


######## 4)
#Test whether ant-tanager body size predicts their brightness for each status group separately and plot the results.

#A) Separate out the dominant and helper data
doms <- subset(tan.dat, tan.dat$status=="dominant")
help <- subset(tan.dat, tan.dat$status=="helper")

#B) Run a linear regression on the data
reg.model.dom <- lm(brightness~mass, data=dom)
reg.model.help <- lm(brightness~mass, data=help)

summary(reg.model.dom)
summary(reg.model.help)

#C) Plot the results together on the same plot using the points function. Have the helper and dominant points have different shapes and colors. Plot the trendlines, regardless of their significance. Add a legend to your plot.
plot(brightness~mass, data=doms, ylab="Percent Brightness (%)", xlab="Mass (g)", col="black", pch=15, ylim=range(tan.dat$brightness), xlim=range(tan.dat$mass))
abline(reg.model.dom, col="black")
points(brightness~mass, data=help, pch=17, col="red")
abline(reg.model.help, col="red")
legend("topright", legend=c("Dominant", "Helper", "Dominant Best-fit", "Helper Best Fit"), bty="n", col=c("black","red","black","red"), pch=c(15,17,NA,NA), lty=c(NA,NA,1,1))

